/*This file has been prepared for Doxygen automatic documentation generation.*/
//! \file *********************************************************************
//!
//! \brief This file manages the CDC task.
//!
//! - Compiler:           IAR EWAVR and GNU GCC for AVR
//! - Supported devices:  AT90USB162, AT90USB82
//!
//! \author               Atmel Corporation: http://www.atmel.com \n
//!                       Support and FAQ: http://support.atmel.no/
//!
//! ***************************************************************************

/* Copyright (c) 2007, Atmel Corporation All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * 3. The name of ATMEL may not be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL ``AS IS'' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE EXPRESSLY AND
 * SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

//_____  I N C L U D E S ___________________________________________________

#include "config.h"
#include "conf_usb.h"
#include "cdc_rf_task.h"
#include "lib_mcu/usb/usb_drv.h"
#include "usb_descriptors.h"
#include "modules/usb/device_chap9/usb_standard_request.h"
#include "usb_specific_request.h"
#include "lib_mcu/spi/spi_lib.h"
#include "lib_board/nrf24l01/nRF_API.h"

//#include <stdio.h>



//_____ M A C R O S ________________________________________________________





//_____ D E F I N I T I O N S ______________________________________________



//_____ D E C L A R A T I O N S ____________________________________________


volatile U8 cpt_sof;
volatile U8 led_tx_flash=0;
volatile U8 led_rx_flash=0;
volatile U16 cpt_sof_led;

         S_line_coding line_coding;
         U8 rx_buffer[RF_BUFFER_SIZE];
         U8 tx_buffer[RF_BUFFER_SIZE];



         U8 tx_counter;
         U8 rx_counter;

#define Flash_tx_led()  (led_tx_flash=0,Led1_on())
#define Flash_rx_led()  (led_rx_flash=0,Led0_on())
         

//! @brief This function initializes the hardware ressources required for CDC demo.
//!
//!
//! @param none
//!
//! @return none
//!
//!/
void cdc_rf_task_init(void)
{
   volatile U32 tempo;
   
   Leds_init();
   //Init nr24L01 driver
   NRF_port_init();
   spi_init(SPI_MASTER);   
   NRF_enable();            // Enable receiver
   NRF_disable();            // Enable receiver
   for(tempo=0;tempo<FOSC/10;tempo++);     
   NRF_init_rx();           // Set nRf primary receiver

   NRF_set_payload(0,RF_BUFFER_SIZE);   // Pipe 0 receiver is 32 bytes
   NRF_enable();            // Enable receiver

   tx_counter = 0;
   rx_counter = 0;
   Usb_enable_sof_interrupt();
}





//! @brief Entry point of the uart cdc management
//!
//! This function links the uart and the USB bus.
//!
//! @param none
//!
//! @return none
void cdc_rf_task(void)
{
   U8 i,j;

   if(Is_device_enumerated()) //Enumeration processs OK ?
   {
      if(cpt_sof>=NB_MS_BEFORE_FLUSH && tx_counter!=0 )  //Flush buffer in Timeout
      {
         cpt_sof=0;
         usb_flush();
      }

      if(Is_NRF_IRQ())
      {
         if (Is_NRF_received())              //Something on RF ?
         {
            NRF_rx_buffer(rx_buffer,RF_BUFFER_SIZE);     //Read data buffer from Rf
            i=rx_buffer[0];                  // Get number of data byte
            for(j=1;j<=i;j++)
            {
               usb_putchar(rx_buffer[j]);
            }
            Flash_rx_led();
            NRF_ack_received();
         }
      }
      

      if(usb_test_hit())
      {
         tx_buffer[0]=rx_counter;
         for(j=1;j<=tx_buffer[0];j++)
         {
            tx_buffer[j]=usb_getchar();
         }
         NRF_init_tx();                   // RF is Tx mode
         NRF_tx_buffer(tx_buffer,RF_BUFFER_SIZE);       // Send data to Rf
         while(Is_not_NRF_IRQ());         // Wait event from Rf
         if(Is_NRF_transmit())            // Data sent ?
         {
            NRF_ack_transmit();
            Flash_tx_led();
         }
         else if (Is_NRF_timeout())
         {
            NRF_ack_timeout();
         }
         NRF_init_rx();
      }
   }
}



//! @brief sof_action
//!
//! USB Start Of Frame Interrupt user subroutine, executed each 1ms
//!
//! @param none
//!
//! @return none
void sof_action()
{

   cpt_sof++;
   if(led_tx_flash<=LED_FLASH_DELAY)
   {
     led_tx_flash++;
   }
   if(led_tx_flash==LED_FLASH_DELAY)
   {
      Led1_off();     
   }
   
   if(led_rx_flash<=LED_FLASH_DELAY)
   {
     led_rx_flash++;
   }
   if(led_rx_flash==LED_FLASH_DELAY)
   {
      Led0_off();     
   }
   

   if(cpt_sof_led++>=RF_LEDS_OFF_DELAY+RF_LEDS_FLASH_DELAY+1) cpt_sof_led=0;
   if(cpt_sof_led==RF_LEDS_OFF_DELAY)
   {
       Led0_on();
       Led1_on();
   }
   if(cpt_sof_led==RF_LEDS_OFF_DELAY+RF_LEDS_FLASH_DELAY)
   {
       Led0_off();
       Led1_off();
   }

}


/**
  * @brief This function checks if a character has been received on the USB bus.
  *
  * @return bit (true if a byte is ready to be read)
  */
bit usb_test_hit(void)
{
  if (!rx_counter)
  {
    Usb_select_endpoint(TX_EP);
    if (Is_usb_receive_out())
    {
      rx_counter = Usb_byte_counter();
      if (!rx_counter)
      {
        Usb_ack_receive_out();
      }
    }
  }
  return (rx_counter!=0);
}

/**
  * @brief This function reads one byte from the USB bus
  *
  * If one byte is present in the USB fifo, this byte is returned. If no data
  * is present in the USB fifo, this function waits for USB data.
  *
  * @return U8 byte received
  */
char usb_getchar(void)
{
  register Uchar data_rx;

  Usb_select_endpoint(TX_EP);
  if (!rx_counter) while (!usb_test_hit());
  data_rx=Usb_read_byte();
  rx_counter--;
  if (!rx_counter) Usb_ack_receive_out();
  return data_rx;
}


/**
  * @brief This function checks if the USB emission buffer is ready to accept at
  * at least 1 byte
  *
  * @return Boolean. TRUE if the firmware can write a new byte to transmit.
  */
bit usb_tx_ready(void)
{
  if (!Is_usb_write_enabled())
  {
    return FALSE;
  }
  return TRUE;
}

/**
  * @brief This function fills the USB transmit buffer with the new data. This buffer
  * is sent if complete. To flush this buffer before waiting full, launch
  * the rf_usb_flush() function.
  *
  * @param data_to_send
  *
  * @return
  */
int usb_putchar(int data_to_send)
{
  	Usb_select_endpoint(RX_EP);
  	while(!usb_tx_ready()); // Wait Endpoint ready
	Usb_write_byte(data_to_send);
	tx_counter++;
  	if(!Is_usb_write_enabled()) //If Endpoint full -> flush
     {
   	usb_flush();
     }
	return data_to_send;
}


/**
  * @brief This function sends the data stored in the USB transmit buffer.
  * This function does nothing if there is no data in the buffer.
  */
void usb_flush (void)
{
   Usb_select_endpoint(RX_EP);
   Usb_send_in();
	tx_counter = 0;
}


